<template>
<div :id="chartId" :style="{'width':'100%', 'height':'100%'}"></div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  props: {
    chartId: {
      type: String,
      default: 'echart'
    },
    chartOption: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  computed: {
    screenSize() {
      return this.$store.state.screenSize
    }
  },
  watch: {
    chartOption: {
      handler(newVal, oldVal) {
        this.echartOptions = this.chartOption
        this.$nextTick(() => {
          this.drawEchart()
        })
      },
      deep: true // 对象内部属性的监听，关键。
    },
    screenSize() {
      // console.log(444)
      this.chart.setOption(this.echartOptions)
      this.chart.resize()
    }
  },
  data() {
    return {
      echartOptions: {},
      chart: null
    }
  },
  mounted() {
    // console.log(222)
    this.$nextTick(() => {
      this.echartOptions = this.chartOption
      this.drawEchart()
    })
  },
  activated() {
    // console.log(1111)
    if (this.chart) {
      this.chart.resize()
    }
  },
  methods: {
    drawEchart() {
      // let legendIconWidth = document.body.clientWidth > 1280 ? (document.body.clientWidth > 1440 ? 14 : (document.body.clientWidth > 1680 ? 16 : 14)) : 12
      // 基于准备好的dom，初始化echarts实例
      const that = this
      if (
        //判断是否存在echarts实例化对象,如果存在则销毁
        that.chart != null &&
        that.chart != '' &&
        that.chart != undefined
      ) {
        that.chart.dispose()
      }
      const myChart = echarts.init(document.getElementById(that.chartId))
      myChart.on('click', params => {
        // 控制台打印数据的名称
        // console.log(params.name);
        that.$emit('chartClick', params)
      })
      that.chart = myChart
      // if(that.echartOptions.legend){
      //   that.echartOptions.legend.itemWidth = legendIconWidth
      //   that.echartOptions.legend.itemHeight = legendIconWidth
      // }
      that.chart.clear()
      // 绘制图表
      myChart.setOption(that.echartOptions)
      setTimeout(() => {
        that.$nextTick(() => {
          myChart.resize()
        })
      }, 10)
    }
  }
}
</script>

<style lang="scss" scoped>

</style>
